Enum sg_marketplace::msg::QueryMsg
source · [−]pub enum QueryMsg {
Show 23 variants
Collections {
start_after: Option<Collection>,
limit: Option<u32>,
},
Ask {
collection: Collection,
token_id: TokenId,
},
Asks {
collection: Collection,
include_inactive: Option<bool>,
start_after: Option<TokenId>,
limit: Option<u32>,
},
ReverseAsks {
collection: Collection,
include_inactive: Option<bool>,
start_before: Option<TokenId>,
limit: Option<u32>,
},
AsksSortedByPrice {
collection: Collection,
include_inactive: Option<bool>,
start_after: Option<AskOffset>,
limit: Option<u32>,
},
ReverseAsksSortedByPrice {
collection: Collection,
include_inactive: Option<bool>,
start_before: Option<AskOffset>,
limit: Option<u32>,
},
AskCount {
collection: Collection,
},
AsksBySeller {
seller: Seller,
include_inactive: Option<bool>,
start_after: Option<CollectionOffset>,
limit: Option<u32>,
},
Bid {
collection: Collection,
token_id: TokenId,
bidder: Bidder,
},
BidsByBidder {
bidder: Bidder,
start_after: Option<CollectionOffset>,
limit: Option<u32>,
},
BidsByBidderSortedByExpiration {
bidder: Bidder,
start_after: Option<CollectionOffset>,
limit: Option<u32>,
},
Bids {
collection: Collection,
token_id: TokenId,
start_after: Option<Bidder>,
limit: Option<u32>,
},
BidsSortedByPrice {
collection: Collection,
start_after: Option<BidOffset>,
limit: Option<u32>,
},
ReverseBidsSortedByPrice {
collection: Collection,
start_before: Option<BidOffset>,
limit: Option<u32>,
},
CollectionBid {
collection: Collection,
bidder: Bidder,
},
CollectionBidsByBidder {
bidder: Bidder,
start_after: Option<CollectionOffset>,
limit: Option<u32>,
},
CollectionBidsByBidderSortedByExpiration {
bidder: Collection,
start_after: Option<CollectionBidOffset>,
limit: Option<u32>,
},
CollectionBidsSortedByPrice {
collection: Collection,
start_after: Option<CollectionBidOffset>,
limit: Option<u32>,
},
ReverseCollectionBidsSortedByPrice {
collection: Collection,
start_before: Option<CollectionBidOffset>,
limit: Option<u32>,
},
AskHooks {},
BidHooks {},
SaleHooks {},
Params {},
}Variants
Collections
List of collections that have asks on them
Return type: CollectionsResponse
Ask
Get the current ask for specific NFT
Return type: CurrentAskResponse
Asks
Fields
collection: CollectionGet all asks for a collection
Return type: AsksResponse
ReverseAsks
Fields
collection: CollectionGet all asks for a collection in reverse
Return type: AsksResponse
AsksSortedByPrice
Fields
collection: CollectionGet all asks for a collection, sorted by price
Return type: AsksResponse
ReverseAsksSortedByPrice
Fields
collection: CollectionGet all asks for a collection, sorted by price in reverse
Return type: AsksResponse
AskCount
Fields
collection: CollectionCount of all asks
Return type: AskCountResponse
AsksBySeller
Get all asks by seller
Return type: AsksResponse
Bid
Get data for a specific bid
Return type: BidResponse
BidsByBidder
Get all bids by a bidder
Return type: BidsResponse
BidsByBidderSortedByExpiration
Get all bids by a bidder, sorted by expiration
Return type: BidsResponse
Bids
Get all bids for a specific NFT
Return type: BidsResponse
BidsSortedByPrice
Get all bids for a collection, sorted by price
Return type: BidsResponse
ReverseBidsSortedByPrice
Get all bids for a collection, sorted by price in reverse
Return type: BidsResponse
CollectionBid
Get data for a specific collection bid
Return type: CollectionBidResponse
CollectionBidsByBidder
Get all collection bids by a bidder
Return type: CollectionBidsResponse
CollectionBidsByBidderSortedByExpiration
Get all collection bids by a bidder, sorted by expiration
Return type: CollectionBidsResponse
CollectionBidsSortedByPrice
Get all collection bids for a collection sorted by price
Return type: CollectionBidsResponse
ReverseCollectionBidsSortedByPrice
Get all collection bids for a collection sorted by price in reverse
Return type: CollectionBidsResponse
AskHooks
Fields
Show all registered ask hooks
Return type: HooksResponse
BidHooks
Fields
Show all registered bid hooks
Return type: HooksResponse
SaleHooks
Fields
Show all registered sale hooks
Return type: HooksResponse
Params
Fields
Get the config for the contract
Return type: ParamsResponse